==> metadata-0.9.0-sources.jar: sila2/org/silastandard/core/authorizationservice/v1/AuthorizationServiceGrpc.java <==
package sila2.org.silastandard.core.authorizationservice.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.50.2)",
    comments = "Source: AuthorizationService.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AuthorizationServiceGrpc {

  private AuthorizationServiceGrpc() {}

  public static final String SERVICE_NAME = "sila2.org.silastandard.core.authorizationservice.v1.AuthorizationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters,
      sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getGetFCPAffectedByMetadataAccessTokenMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Get_FCPAffectedByMetadata_AccessToken",
      requestType = sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters.class,
      responseType = sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters,
      sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getGetFCPAffectedByMetadataAccessTokenMethod() {
    io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters, sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getGetFCPAffectedByMetadataAccessTokenMethod;
    if ((getGetFCPAffectedByMetadataAccessTokenMethod = AuthorizationServiceGrpc.getGetFCPAffectedByMetadataAccessTokenMethod) == null) {
      synchronized (AuthorizationServiceGrpc.class) {
        if ((getGetFCPAffectedByMetadataAccessTokenMethod = AuthorizationServiceGrpc.getGetFCPAffectedByMetadataAccessTokenMethod) == null) {
          AuthorizationServiceGrpc.getGetFCPAffectedByMetadataAccessTokenMethod = getGetFCPAffectedByMetadataAccessTokenMethod =
              io.grpc.MethodDescriptor.<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters, sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Get_FCPAffectedByMetadata_AccessToken"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses.getDefaultInstance()))
              .setSchemaDescriptor(new AuthorizationServiceMethodDescriptorSupplier("Get_FCPAffectedByMetadata_AccessToken"))
              .build();
        }
      }
    }
    return getGetFCPAffectedByMetadataAccessTokenMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AuthorizationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceStub>() {
        @java.lang.Override
        public AuthorizationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationServiceStub(channel, callOptions);
        }
      };
    return AuthorizationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AuthorizationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceBlockingStub>() {
        @java.lang.Override
        public AuthorizationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationServiceBlockingStub(channel, callOptions);
        }
      };
    return AuthorizationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AuthorizationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceFutureStub>() {
        @java.lang.Override
        public AuthorizationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationServiceFutureStub(channel, callOptions);
        }
      };
    return AuthorizationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class AuthorizationServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void getFCPAffectedByMetadataAccessToken(sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetFCPAffectedByMetadataAccessTokenMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetFCPAffectedByMetadataAccessTokenMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters,
                sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses>(
                  this, METHODID_GET_FCPAFFECTED_BY_METADATA_ACCESS_TOKEN)))
          .build();
    }
  }

  /**
   */
  public static final class AuthorizationServiceStub extends io.grpc.stub.AbstractAsyncStub<AuthorizationServiceStub> {
    private AuthorizationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationServiceStub(channel, callOptions);
    }

    /**
     */
    public void getFCPAffectedByMetadataAccessToken(sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetFCPAffectedByMetadataAccessTokenMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class AuthorizationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<AuthorizationServiceBlockingStub> {
    private AuthorizationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses getFCPAffectedByMetadataAccessToken(sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetFCPAffectedByMetadataAccessTokenMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class AuthorizationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<AuthorizationServiceFutureStub> {
    private AuthorizationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getFCPAffectedByMetadataAccessToken(
        sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetFCPAffectedByMetadataAccessTokenMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_FCPAFFECTED_BY_METADATA_ACCESS_TOKEN = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AuthorizationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AuthorizationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_FCPAFFECTED_BY_METADATA_ACCESS_TOKEN:
          serviceImpl.getFCPAffectedByMetadataAccessToken((sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters) request,
              (io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AuthorizationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AuthorizationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AuthorizationService");
    }
  }

  private static final class AuthorizationServiceFileDescriptorSupplier
      extends AuthorizationServiceBaseDescriptorSupplier {
    AuthorizationServiceFileDescriptorSupplier() {}
  }

  private static final class AuthorizationServiceMethodDescriptorSupplier
      extends AuthorizationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AuthorizationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AuthorizationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AuthorizationServiceFileDescriptorSupplier())
              .addMethod(getGetFCPAffectedByMetadataAccessTokenMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> metadata-0.12.0-sources.jar: sila2/org/silastandard/core/authorizationservice/v1/AuthorizationServiceGrpc.java <==
package sila2.org.silastandard.core.authorizationservice.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.50.2)",
    comments = "Source: sila2/org/silastandard/core/authorizationservice/v1/AuthorizationService.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AuthorizationServiceGrpc {

  private AuthorizationServiceGrpc() {}

  public static final String SERVICE_NAME = "sila2.org.silastandard.core.authorizationservice.v1.AuthorizationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters,
      sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getGetFCPAffectedByMetadataAccessTokenMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Get_FCPAffectedByMetadata_AccessToken",
      requestType = sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters.class,
      responseType = sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters,
      sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getGetFCPAffectedByMetadataAccessTokenMethod() {
    io.grpc.MethodDescriptor<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters, sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getGetFCPAffectedByMetadataAccessTokenMethod;
    if ((getGetFCPAffectedByMetadataAccessTokenMethod = AuthorizationServiceGrpc.getGetFCPAffectedByMetadataAccessTokenMethod) == null) {
      synchronized (AuthorizationServiceGrpc.class) {
        if ((getGetFCPAffectedByMetadataAccessTokenMethod = AuthorizationServiceGrpc.getGetFCPAffectedByMetadataAccessTokenMethod) == null) {
          AuthorizationServiceGrpc.getGetFCPAffectedByMetadataAccessTokenMethod = getGetFCPAffectedByMetadataAccessTokenMethod =
              io.grpc.MethodDescriptor.<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters, sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Get_FCPAffectedByMetadata_AccessToken"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses.getDefaultInstance()))
              .setSchemaDescriptor(new AuthorizationServiceMethodDescriptorSupplier("Get_FCPAffectedByMetadata_AccessToken"))
              .build();
        }
      }
    }
    return getGetFCPAffectedByMetadataAccessTokenMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AuthorizationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceStub>() {
        @java.lang.Override
        public AuthorizationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationServiceStub(channel, callOptions);
        }
      };
    return AuthorizationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AuthorizationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceBlockingStub>() {
        @java.lang.Override
        public AuthorizationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationServiceBlockingStub(channel, callOptions);
        }
      };
    return AuthorizationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AuthorizationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AuthorizationServiceFutureStub>() {
        @java.lang.Override
        public AuthorizationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AuthorizationServiceFutureStub(channel, callOptions);
        }
      };
    return AuthorizationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class AuthorizationServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void getFCPAffectedByMetadataAccessToken(sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetFCPAffectedByMetadataAccessTokenMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetFCPAffectedByMetadataAccessTokenMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters,
                sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses>(
                  this, METHODID_GET_FCPAFFECTED_BY_METADATA_ACCESS_TOKEN)))
          .build();
    }
  }

  /**
   */
  public static final class AuthorizationServiceStub extends io.grpc.stub.AbstractAsyncStub<AuthorizationServiceStub> {
    private AuthorizationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationServiceStub(channel, callOptions);
    }

    /**
     */
    public void getFCPAffectedByMetadataAccessToken(sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request,
        io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGetFCPAffectedByMetadataAccessTokenMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class AuthorizationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<AuthorizationServiceBlockingStub> {
    private AuthorizationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses getFCPAffectedByMetadataAccessToken(sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGetFCPAffectedByMetadataAccessTokenMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class AuthorizationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<AuthorizationServiceFutureStub> {
    private AuthorizationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AuthorizationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AuthorizationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses> getFCPAffectedByMetadataAccessToken(
        sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGetFCPAffectedByMetadataAccessTokenMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_FCPAFFECTED_BY_METADATA_ACCESS_TOKEN = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AuthorizationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AuthorizationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_FCPAFFECTED_BY_METADATA_ACCESS_TOKEN:
          serviceImpl.getFCPAffectedByMetadataAccessToken((sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Parameters) request,
              (io.grpc.stub.StreamObserver<sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.Get_FCPAffectedByMetadata_AccessToken_Responses>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AuthorizationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AuthorizationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return sila2.org.silastandard.core.authorizationservice.v1.AuthorizationServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AuthorizationService");
    }
  }

  private static final class AuthorizationServiceFileDescriptorSupplier
      extends AuthorizationServiceBaseDescriptorSupplier {
    AuthorizationServiceFileDescriptorSupplier() {}
  }

  private static final class AuthorizationServiceMethodDescriptorSupplier
      extends AuthorizationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AuthorizationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AuthorizationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AuthorizationServiceFileDescriptorSupplier())
              .addMethod(getGetFCPAffectedByMetadataAccessTokenMethod())
              .build();
        }
      }
    }
    return result;
  }
}
